@@ -9,6 +9,17 @@ from enum import Enum
 
 from conda import __version__ as CONDA_VERSION
 
+
+try:
+    # This monkey patch is addressed at #1825. The ensure_use_local is an outdated vestige
+    #   and no longer has any relevant effect.
+    import conda.cli.common
+    conda.cli.common.ensure_use_local = lambda x: None
+except ImportError:
+    # no need to patch if it doesn't exist
+    pass
+
+
 from conda.plan import display_actions, execute_actions, execute_plan, install_actions
 display_actions, execute_actions, execute_plan = display_actions, execute_actions, execute_plan
 install_actions = install_actions
@@ -151,7 +162,7 @@ if parse_version(CONDA_VERSION) >= parse_version("4.2"):
 
     get_rc_urls = lambda: list(context.channels)
     get_prefix = partial(context_get_prefix, context)
-    cc_conda_build = context.conda_build
+    cc_conda_build = context.conda_build if hasattr(context, 'conda_build') else {}
 
     # disallow softlinks.  This avoids a lot of dumb issues, at the potential cost of disk space.
     os.environ['CONDA_ALLOW_SOFTLINKS'] = 'false'
