@@ -471,7 +471,8 @@ def skeletonize(packages, output_dir=".", version=None, git_tag=None,
 
         if is_github_url:
             rm_rf(config.work_dir)
-            source.git_source({'git_url': package}, '.', config=config)
+            m = metadata.MetaData.fromdict({'source': {'git_url': package}})
+            source.git_source(m, config=config)
             git_tag = git_tag[0] if git_tag else get_latest_git_tag(config)
             p = subprocess.Popen(['git', 'checkout', git_tag], stdout=subprocess.PIPE,
                                  stderr=subprocess.PIPE, cwd=config.work_dir)
